# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog],
and this project adheres to [Semantic Versioning].

## Unreleased

- /

## 0.1.2 - 2025-06-24

- Allow specifying noise scale in CEEMDAN [#2](https://github.com/felixgwilliams/pyemd-rs/issues/2)
- Allow switching off parallelism [#3](https://github.com/felixgwilliams/pyemd-rs/issues/3)

## 0.1.1 - 2025-06-22

- remove dependency on `ndarray-linalg` for better performance and more platform support

## 0.1.0 - 2025-06-22

- initial release

<!-- Links -->
[keep a changelog]: https://keepachangelog.com/en/1.0.0/
[semantic versioning]: https://semver.org/spec/v2.0.0.html
